yt.visualization.fixed\_resolution\_filters module
==================================================

.. automodule:: yt.visualization.fixed_resolution_filters
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
